@@ -157,7 +157,8 @@ class BaseOperator(metaclass=abc.ABCMeta):
         Returns:
             dict: XCOM dictionary
         """
-        xcom_obj = output_obj.dict()
+        # xcom_obj = output_obj.dict()
+        xcom_obj = json.loads(output_obj.json())
         if not isinstance(xcom_obj, dict):
             print(f"Operator {self.__class__.__name__} is not returning a valid XCOM object. Auto-generating a base XCOM for it...")
             self.logger.info(f"Operator {self.__class__.__name__} is not returning a valid XCOM object. Auto-generating a base XCOM for it...")
