@@ -12,8 +12,8 @@ from flowui.utils import dict_deep_update
 from flowui.logger import get_configured_logger
 from flowui.schemas.shared_storage import StorageSource
 from flowui.schemas.container_resources import ContainerResourcesModel
-from pathlib import Path
 from kubernetes import client, config
+import os
 
 class Task(object):
     """
@@ -144,143 +144,39 @@ class Task(object):
             all_volume_mounts = []
 
             ######################## For local Operators dev ###########################################
+            if os.environ.get('FLOWUI_DEV_MODE') == 'local':
+                source_image = self.operator.get('source_image')
+                repository_raw_project_name = str(source_image).split('/')[1].split(':')[0]
+                persistent_volume_claim_name = 'pvc-{}'.format(str(repository_raw_project_name.lower().replace('_', '-')))
 
-            # TODO solve the hot reloading for multiple repositories
-            # The idea is to create a PV and PVC for each repository dynamically using k8s api
-            # The problem found is that I can't connect to the k8s api from this pod, it is giving forbidden
-            # probably because the service account is not configured correctly
-            # Error found: User "system:serviceaccount:default:airflow-scheduler" cannot list resource - this is because the scheduler doesn't have enough permissions in its service account rolebinding
+                volume_dev_operators = k8s.V1Volume(
+                    name='dev-op-{path_name}'.format(path_name=str(repository_raw_project_name.lower().replace('_', '-'))),
+                    persistent_volume_claim=k8s.V1PersistentVolumeClaimVolumeSource(
+                        claim_name=persistent_volume_claim_name
+                    ),
+                )
+                volume_mount_dev_operators = k8s.V1VolumeMount(
+                    name='dev-op-{path_name}'.format(path_name=str(repository_raw_project_name.lower().replace('_', '-'))), 
+                    mount_path=f'/home/flowui/operators_repository',
+                    sub_path=None, 
+                    read_only=True
+                )
+                all_volumes.append(volume_dev_operators)
+                all_volume_mounts.append(volume_mount_dev_operators)
 
-            # Adding this to the ariflow scheduler-serviceaccount.yaml would probably give enough permissions but I think it could be a security issue
-            """
-            ---
-            kind: ClusterRoleBinding
-            apiVersion: rbac.authorization.k8s.io/v1
-            metadata:
-            name: full-access-user-clusterrolebinding
-            subjects:
-            - kind: ServiceAccount
-            name: {{ include "scheduler.serviceAccountName" . }}
-            namespace: default
-            roleRef:
-            kind: ClusterRole
-            name: cluster-admin
-            apiGroup: rbac.authorization.k8s.io
-            """
-            # paths_to_test = [
-            #     "/home/vinicius/Documents/work/tauffer/flowui_example_operators_repository",
-            #     '/home/vinicius/Documents/work/tauffer/flowui_ml_operators',
-            #     '/home/vinicius/Documents/work/tauffer/flowui_social_media_operators'
-            # ]
-
-            # for path in paths_to_test:
-            #     path_name = Path(path).name
-            #     persistent_volume_name = 'pv-{}'.format(str(path_name.lower().replace('_', '-')))
-            #     persistent_volume_claim_name = 'pvc-{}'.format(str(path_name.lower().replace('_', '-')))
-            #     print('creating pv and pvc for path: {}'.format(path))
-
-            #     pvc_exists = False
-            #     try:
-            #         self.logger.info('Reading PVC', persistent_volume_claim_name)
-            #         self.k8s_client.read_namespaced_persistent_volume_claim(name=persistent_volume_claim_name, namespace='default')
-            #         self.logger.info('PVC read successfully')
-            #         pvc_exists = True
-            #     except client.rest.ApiException as e:
-            #         self.logger.exception('Error reading PVC', e)
-            #         if e.status != 404:
-            #             raise e
-                    
-            #     if not pvc_exists:
-            #         pvc = client.V1PersistentVolumeClaim(
-            #             metadata=client.V1ObjectMeta(name=persistent_volume_claim_name),
-            #             spec=client.V1PersistentVolumeClaimSpec(
-            #                 access_modes=["ReadOnlyMany"],
-            #                 volume_name=persistent_volume_name,
-            #                 resources=client.V1ResourceRequirements(
-            #                     requests={"storage": "300Mi"}
-            #                 ),
-            #                 storage_class_name="standard"
-            #             )
-            #         )
-            #         self.logger.info('Creating PVC', persistent_volume_claim_name)
-            #         self.k8s_client.create_namespaced_persistent_volume_claim(namespace="default", body=pvc)
-
-            #     pv_exists = False
-            #     try:
-            #         self.logger.info('Reading PV', persistent_volume_name)
-            #         self.k8s_client.read_persistent_volume(name=persistent_volume_name)
-            #         self.logger.info('PV read successfully')
-            #         pv_exists = True
-            #     except client.rest.ApiException as e:
-            #         self.logger.exception('Error reading PV', e)
-            #         if e.status != 404:
-            #             raise e
-
-            #     if not pv_exists:
-            #         pv = client.V1PersistentVolume(
-            #             metadata=client.V1ObjectMeta(name=persistent_volume_name),
-            #             spec=client.V1PersistentVolumeSpec(
-            #                 access_modes=["ReadWriteOnce"],
-            #                 capacity={"storage": "1Gi"},
-            #                 persistent_volume_reclaim_policy="Retain",
-            #                 storage_class_name="standard",
-            #                 host_path=client.V1HostPathVolumeSource(path=f"/{path_name}"),
-            #                 claim_ref=client.V1ObjectReference(
-            #                     namespace="default",
-            #                     name=persistent_volume_claim_name,
-            #                     kind="PersistentVolumeClaim"
-            #                 ),
-            #                 node_affinity=client.V1VolumeNodeAffinity(
-            #                     required=client.V1NodeSelector(
-            #                         node_selector_terms=[
-            #                             client.V1NodeSelectorTerm(
-            #                                 match_expressions=[
-            #                                     client.V1NodeSelectorRequirement(
-            #                                         key="kubernetes.io/hostname",
-            #                                         operator="In",
-            #                                         values=["flowui-cluster-worker"]
-            #                                     )
-            #                                 ]
-            #                             )
-            #                         ]
-            #                     )
-            #                 )
-            #             )
-            #         )
-            #         self.logger.info('Creating pv', persistent_volume_name)
-            #         self.k8s_client.create_persistent_volume(body=pv)
-
-            #     # Need to add check to see if the pv and pvc already exist because scheduler will try to create them again on every import
-            #     volume_dev_operators = k8s.V1Volume(
-            #         name='dev-op-{path_name}'.format(path_name=str(path_name.lower().replace('_', '-'))),
-            #         persistent_volume_claim=k8s.V1PersistentVolumeClaimVolumeSource(
-            #             claim_name=persistent_volume_claim_name
-            #         ),
-            #     )
-            #     volume_mount_dev_operators = k8s.V1VolumeMount(
-            #         name='dev-op-{path_name}'.format(path_name=str(path_name.lower().replace('_', '-'))), 
-            #         mount_path=f'/home/flowui/{path_name}',
-            #         sub_path=None, 
-            #         read_only=True
-            #     )
-            #     all_volumes.append(volume_dev_operators)
-                #all_volume_mounts.append(volume_mount_dev_operators)
-
-            ############################################################################################
-
-            ######################## For local FlowUI dev ###############################################
-            # volume_dev = k8s.V1Volume(
-            #     name='jobs-persistent-storage-dev',
-            #     persistent_volume_claim=k8s.V1PersistentVolumeClaimVolumeSource(claim_name='flowui-dev-volume-claim'),
-            # )
-            # volume_mount_dev = k8s.V1VolumeMount(
-            #     name='jobs-persistent-storage-dev', 
-            #     mount_path='/home/flowui_dev', 
-            #     sub_path=None, 
-            #     read_only=True
-            # )
-            # all_volumes.append(volume_dev)
-            # all_volume_mounts.append(volume_mount_dev)
+                ######################## For local FlowUI dev ###############################################
+                volume_dev = k8s.V1Volume(
+                    name='jobs-persistent-storage-dev',
+                    persistent_volume_claim=k8s.V1PersistentVolumeClaimVolumeSource(claim_name='flowui-dev-volume-claim'),
+                )
+                volume_mount_dev = k8s.V1VolumeMount(
+                    name='jobs-persistent-storage-dev', 
+                    mount_path='/home/flowui_dev', 
+                    sub_path=None, 
+                    read_only=True
+                )
+                all_volumes.append(volume_dev)
+                all_volume_mounts.append(volume_mount_dev)
             ############################################################################################
 
             pod_startup_timeout_in_seconds = 600
